==> components-1.0.0.tgz: package/src/main.tsx <==
import ReactDOM from 'react-dom';
import ButtonDeveloper from './components/developer/button-developer';
import "./index.css";
import CardContentDeveloper from '@/components/developer/card-content-developer';
import CardClickableDeveloper from '@/components/developer/card-clickable-developer';
import InputDeveloper from '@/components/developer/input-developer';

export { default as CardContentDeveloper } from '@/components/developer/card-content-developer';
export { default as CardClickableDeveloper } from '@/components/developer/card-clickable-developer';
export { default as InputDeveloper } from '@/components/developer/input-developer';

function App() {
  return (
    <div className="container mx-auto text-center bg-[#f2f4f7] h-screen">
      <div className='h-[12px]'>
        <div className='h-[12px] bg-[#3d3dff] w-full absolute left-0' />
      </div>
      <div className='flex flex-col items-start py-10'>
        <h1 className="text-3xl font-bold ">Biblioteca componentes</h1>
        <p className="text-lg ">Esta é uma biblioteca de componentes para evostack.</p>
      </div>
      <div className='flex flex-col gap-20'>
        {/* Botão  */}
        <ButtonDeveloper >
          Button
        </ButtonDeveloper>
        {/* Card Content  */}
        <CardContentDeveloper index={0} initial="hidden" animate="visible" variants={{ hidden: { opacity: 0 }, visible: { opacity: 1 } }} transition={{ delay: 0, duration: 1 }}>
          <div className='flex flex-col gap-5'>
            Card Contet Developer teste
            <ButtonDeveloper >
              Clique aqui
            </ButtonDeveloper>
          </div>
        </CardContentDeveloper>
        {/* Card Clickable  */}
        <CardClickableDeveloper index={0} transition={{ delay: 0, duration: 1 }}>
          <div className='w-[150px] items-center flex flex-col gap-[16px]'>
            <div className='w-[56px] h-[56px] rounded-full bg-[#ebebff]'>

            </div>
            Área PIX
          </div>
        </CardClickableDeveloper>

        <InputDeveloper />
      </div>
    </div>
  );
}

ReactDOM.render(<App />, document.getElementById('root'));

==> components-1.0.4.tgz: package/src/main.tsx <==
import ReactDOM from 'react-dom';
import ButtonDeveloper from './components/developer/button-developer';
import "./index.css";
import CardContentDeveloper from './components/developer/card-content-developer';
import CardClickableDeveloper from './components/developer/card-clickable-developer';
import InputDeveloper from './components/developer/input-developer';

export { default as CardContentDeveloper } from './components/developer/card-content-developer';
export { default as CardClickableDeveloper } from './components/developer/card-clickable-developer';
export { default as InputDeveloper } from './components/developer/input-developer';

function App() {
  return (
    <div className="container mx-auto text-center bg-[#f2f4f7] h-screen">
      <div className='h-[12px]'>
        <div className='h-[12px] bg-[#3d3dff] w-full absolute left-0' />
      </div>
      <div className='flex flex-col items-start py-10'>
        <h1 className="text-3xl font-bold ">Biblioteca componentes</h1>
        <p className="text-lg ">Esta é uma biblioteca de componentes para evostack.</p>
      </div>
      <div className='flex flex-col gap-20'>
        {/* Botão  */}
        <ButtonDeveloper >
          Button
        </ButtonDeveloper>
        {/* Card Content  */}
        <CardContentDeveloper index={0} initial="hidden" animate="visible" variants={{ hidden: { opacity: 0 }, visible: { opacity: 1 } }} transition={{ delay: 0, duration: 1 }}>
          <div className='flex flex-col gap-5'>
            Card Contet Developer teste
            <ButtonDeveloper >
              Clique aqui
            </ButtonDeveloper>
          </div>
        </CardContentDeveloper>
        {/* Card Clickable  */}
        <CardClickableDeveloper index={0} transition={{ delay: 0, duration: 1 }}>
          <div className='w-[150px] items-center flex flex-col gap-[16px]'>
            <div className='w-[56px] h-[56px] rounded-full bg-[#ebebff]'>

            </div>
            Área PIX
          </div>
        </CardClickableDeveloper>

        <InputDeveloper />
      </div>
    </div>
  );
}

ReactDOM.render(<App />, document.getElementById('root'));
